#pragma once
#include <vector>
#include <chrono>
#include <memory>
#include "SDL2/SDL.h"
#include "Unit.h"
#include "TextureLoader.h"
#include "Timer.h"



class Game
{
private:
	enum class GameMode {
		loading,
		commandPrompt,
		playing,
		gameOver,
		finished
	} gameModeCurrent;


public:
	Game(SDL_Window* window, SDL_Renderer* renderer, int windowWidth, int windowHeight);
	~Game();


private:
	void loadUnits(SDL_Renderer* renderer, int windowWidth, int windowHeight);
	void processEvents(bool& running);
	void update(float dT);
	void updateUnits(float dT);
	void draw(SDL_Renderer* renderer, int windowWidth, int windowHeight);
	void drawLoading(SDL_Renderer* renderer, int windowWidth, int windowHeight);
	void drawCommandPrompt(SDL_Renderer* renderer, int windowWidth, int windowHeight);
	void drawPlaying(SDL_Renderer* renderer, int windowWidth, int windowHeight);
	void drawFinished(SDL_Renderer* renderer, int windowWidth, int windowHeight);
	bool checkIfGameFinished();
	bool teamStillHasAtLeastOneUnit(Unit::Team team);


	std::vector<std::shared_ptr<Unit>> listUnits;

	SDL_Texture* textureFunOSLoadingLogo = nullptr,
		* textureBottomBar = nullptr,
		* textureBattleTime = nullptr,
		* textureCommandPrompt = nullptr,
		* textureErrorMessage = nullptr;

	Timer timerLoading, timerFinished;
};